<?php

/**
 * @file
 */

use Drupal\Component\Utility\Html;
use Drupal\Core\Render\Element;

/**
 * Prepares variables for the module details templates.
 *
 * Default template: config-purge-modules-details.html.twig.
 *
 * @param array $variables
 *   An associative array containing:
 *   - form: A render element representing the form. The main form element
 *     represents a package, and child elements of the form are individual
 *     projects. Each project (or module) is an associative array containing the
 *     following elements:
 *     - name: The name of the module.
 *     - enable: A checkbox for enabling the module.
 *     - description: A description of the module.
 *
 * @see \Drupal\config_purge\Form\PurgeConfigurationsForm
 */
function template_preprocess_config_purge_modules_details(&$variables): void {
  $form = $variables['form'];

  $variables['modules'] = [];
  // Iterate through all the modules, which are children of this element.
  foreach (Element::children($form) as $key) {
    $module = $form[$key];
    unset($module['enable']['#title']);
    $module['checkbox'] = $module['enable'];
    $id = Html::getUniqueId('module-' . $key);
    $module['id'] = $id;
    $module['enable_id'] = $module['enable']['#id'];
    $module['machine_name'] = $key;

    $variables['modules'][] = $module;
  }
}
