<?php

namespace Drupal\config_purge\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Hook implementations for config_purge.
 */
class ConfigPurgeHooks {

  /**
   * Implements hook_help().
   */
  #[Hook('help')]
  public function help($route_name, RouteMatchInterface $route_match): ?string {
    $output = '';
    switch ($route_name) {
      case 'help.page.config_purge':
        $output .= '<h3>' . t('About') . '</h3>';
        $output .= '<p>' . t('The Configuration purge module allows to delete active configurations of uninstalled modules.') . '</p>';
        return $output;

      case 'config_purge.purge':
        $output .= '<p>' . t('This is a list of uninstalled modules with active configuration. Modules have configuration in the database despite the module is not installed currently.') . '</p>';
        $output .= '<p>' . t('The configurations can be reviewed and deleted in the next step after clicking on the "Purge" button.') . '</p>';
        return $output;
    }

    return NULL;
  }

  /**
   * Implements hook_menu_links_discovered_alter().
   */
  #[Hook('menu_links_discovered_alter')]
  public function menuLinksDiscoveredAlter(&$links): void {
    if (\Drupal::moduleHandler()->moduleExists('admin_toolbar_tools')) {
      // Add the menu link to the Tools menu, but only if the
      // Admin Toolbar Extra Tools module is present.
      $links['admin_toolbar_tools.config.purge'] = [
        'title' => t('Purge'),
        'route_name' => 'config_purge.purge',
        'menu_name' => 'admin',
        'parent' => 'config.sync',
        'weight' => 2.5,
      ];
    }
  }

  /**
   * Implements hook_theme().
   */
  #[Hook('theme')]
  public function theme(): array {
    return [
      'config_purge_modules_details' => [
        'render element' => 'form',
        'file' => 'config_purge.admin.inc',
      ],
    ];
  }

}
